@@ -36,12 +36,14 @@
 #define MAX_SPRITE_FRAMES 30
 
 #include <string.h>
+#include <wchar.h>
 #include <math.h>
 #include <time.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/stat.h>
 #include <dirent.h>
+#include <locale.h>
 
 #include "../config.h"
 
@@ -52,26 +54,62 @@
 
 #endif //  __GLOBALS_H__
 
-#define next_frame(SPRITE) if ((SPRITE)->num_frames) (SPRITE)->cur = (((SPRITE)->cur)+1) % (SPRITE)->num_frames;
-#define rewind(SPRITE) (SPRITE)->cur = 0;
+#define NEXT_FRAME(SPRITE) if ((SPRITE)->num_frames) (SPRITE)->cur = (((SPRITE)->cur)+1) % (SPRITE)->num_frames;
+#define REWIND(SPRITE) (SPRITE)->cur = 0;
 
 #define MIN(x,y) ((x) < (y) ? (x) : (y))
 #define MAX(x,y) ((x) > (y) ? (x) : (y))
 
-typedef struct {
-    char lang[FNLEN];
-    char path[FNLEN];
-    char window[FNLEN];
-    int sfx_volume;
-    int mus_volume;
-    int menu_music;
-} settings;
+/* Goal is to have all global settings here */
+/* (renamed from 'settings' to match tuxmath) */
+typedef struct game_option_type{
+  char default_data_path[FNLEN];
+  char theme_data_path[FNLEN];
+  char user_settings_path[FNLEN];
+  char global_settings_path[FNLEN];
+  char theme_name[FNLEN];
+  char lang[FNLEN];
+  char theme_font_name[FNLEN];
+  int use_english;
+  int fullscreen;
+  int sys_sound;
+  int sfx_volume;
+  int mus_volume;
+  int menu_music;
+  int menu_sound;
+  int speed_up;
+  int show_tux4kids;
+  int debug_on;
+  int o_lives;
+  int sound_vol;
+  int hidden; // Read the README file in the image directory for info on this ;)
+} game_option_type;
+
+/* Default values for game_option_type struct */
+/* They can be changed in the struct to other values at run-time */
+#define DEFAULT_MENU_FONT       "AndikaDesRevG.ttf"
+#define DEFAULT_GAME_FONT       "AndikaDesRevG.ttf" 
+#define DEFAULT_USE_ENGLISH 1
+#define DEFAULT_FULLSCREEN 1
+#define DEFAULT_SYS_SOUND 1
+#define DEFAULT_SFX_VOLUME 100
+#define DEFAULT_MUS_VOLUME 100
+#define DEFAULT_MENU_MUSIC 1
+#define DEFAULT_MENU_SOUND 1
+#define DEFAULT_SPEED_UP 0
+#define DEFAULT_SHOW_TUX4KIDS 1
+#define DEFAULT_DEBUG_ON 0
+#define DEFAULT_O_LIVES 0
+#define DEFAULT_SOUND_VOL 100
+#define DEFAULT_HIDDEN 0
+
+
 
 typedef struct {
-	SDL_Surface *frame[MAX_SPRITE_FRAMES];
-	SDL_Surface *default_img;
-	int num_frames;
-	int cur;
+  SDL_Surface* frame[MAX_SPRITE_FRAMES];
+  SDL_Surface* default_img;
+  int num_frames;
+  int cur;
 } sprite;
 
 #define _(str) gettext (str)
@@ -92,49 +130,50 @@ typedef struct {
  *   all over the place!
  */
 
-#define LOG( str ) if (debugOn) fprintf( stderr, str );
-#define DEBUGCODE if (debugOn) 
-#define DOUT(x) if (debugOn) fprintf(stderr, "%s = %d\n", #x, x);
+#define LOG( str ) if (settings.debug_on) fprintf( stderr, str );
+#define DEBUGCODE if (settings.debug_on) 
+#define DOUT(x) if (settings.debug_on) fprintf(stderr, "%s = %d\n", #x, x);
 
 #if SDL_BYTEORDER == SDL_BIG_ENDIAN
-#define rmask 0xff000000
-#define gmask 0x00ff0000
-#define bmask 0x0000ff00
-#define amask 0x000000ff
+#define RMASK 0xff000000
+#define GMASK 0x00ff0000
+#define BMASK 0x0000ff00
+#define AMASK 0x000000ff
 #else
-#define rmask 0x000000ff
-#define gmask 0x0000ff00
-#define bmask 0x00ff0000
-#define amask 0xff000000
+#define RMASK 0x000000ff
+#define GMASK 0x0000ff00
+#define BMASK 0x00ff0000
+#define AMASK 0xff000000
 #endif
 
-#define menu_font	"GenAI102.ttf" /* or "DejaVuSans-Bold.ttf"  or "FreeSansBold.ttf" */ 	/* was menu.ttf */
-#define menu_font_size	20
 
-#define ttf_font	"GenAI102.ttf" /* or "DejaVuSans-Bold.ttf" or "FreeSansBold.ttf" */  	/* was letters.ttf */
-#define ttf_font_size	20
 
+#define MENU_FONT_SIZE	20
+#define GAME_FONT_SIZE	20
+
+/* Limits on word list size, word length, and on the number of distinct characters */
+/* that can be present within a word list: */
 #define MAX_NUM_WORDS   500
 #define MAX_WORD_SIZE   8
+#define MAX_UNICODES    1024
 
-#define WAIT_MS				2500
-#define	FRAMES_PER_SEC	                50
-#define FULL_CIRCLE		        140
+#define WAIT_MS		2500
+#define	FRAMES_PER_SEC	50
+#define FULL_CIRCLE	140
 
 /* Menu Prototypes */
 enum Game_Type { 
-	QUIT_GAME, CASCADE, OPTIONS, LESSONS,
-	INSTRUCT_CASCADE, CASCADE1, CASCADE2, CASCADE3, CASCADE4,
-	INSTRUCT_LASER,    LASER1,    LASER2,    LASER3,    LASER4,
-	FREETYPE, ASDF, ALL, MAIN, SET_LANGUAGE, PROJECT_INFO, EDIT_WORDLIST,
-	LEVEL1, LEVEL2, LEVEL3, LEVEL4, LASER, INSTRUCT, NOT_CODED, NONE};
+  QUIT_GAME, CASCADE, OPTIONS, LESSONS,
+  INSTRUCT_CASCADE, CASCADE1, CASCADE2, CASCADE3, CASCADE4,
+  INSTRUCT_LASER, LASER1, LASER2, LASER3, LASER4,
+  FREETYPE, ASDF, ALL, MAIN, SET_LANGUAGE, PROJECT_INFO, EDIT_WORDLIST,
+  LEVEL1, LEVEL2, LEVEL3, LEVEL4, LASER, INSTRUCT, NOT_CODED, NONE};
 
 /* Title sequence constants */
-#define PRE_ANIM_FRAMES			10
-#define PRE_FRAME_MULT			3
-#define MENU_SEP			20
+#define PRE_ANIM_FRAMES	 10
+#define PRE_FRAME_MULT	 3
+#define MENU_SEP	 20
 
-/* paths */
 
 #define IMG_REGULAR  0x01
 #define IMG_COLORKEY 0x02
@@ -146,10 +185,14 @@ enum Game_Type {
 
 //Game difficulty levels
 enum { EASY, MEDIUM, HARD, INSANE, INF_PRACT };
-#define NUM_LEVELS		        4
+#define NUM_LEVELS  4
 
-extern SDL_Surface *screen;
-extern TTF_Font  *font;
+extern game_option_type settings;
+
+/* FIXME get rid of as much global data as possible, esp. pointers */
+
+extern SDL_Surface* screen;
+//extern TTF_Font* font;
 extern SDL_Event  event;
 
 extern SDL_Color black;
@@ -159,26 +202,12 @@ extern SDL_Color red;
 extern SDL_Color white;
 extern SDL_Color yellow;
 
-extern SDL_Surface *bkg;
-extern SDL_Surface *letters[255];
+extern SDL_Surface* letters[255]; /* Will be going away */
 
-extern unsigned char ALPHABET[256];
-extern unsigned char KEYMAP[256];
-extern unsigned char FINGER[256][10];
+/* These need some work to support Unicode & i18n: */
+extern wchar_t ALPHABET[256];
 extern int ALPHABET_SIZE;
 
-//global vars
-extern int speed_up;
-extern int show_tux4kids;
-extern int debugOn;
-extern int o_lives;
-extern int sound_vol;
-extern int hidden; // Read the README file in the image directory for info on this ;)
-
-/* Alternative language/word/image/sound theming */
-extern unsigned char realPath[2][FNLEN];
-extern char themeName[FNLEN];
-extern int useEnglish;
 
 enum {
 	WIN_WAV,
@@ -192,10 +221,6 @@ enum {
 	NUM_WAVES
 };
 
-extern Mix_Chunk      *sound[NUM_WAVES];
-extern Mix_Music      *music;
-extern int sys_sound;
-
 #define MUSIC_FADE_OUT_MS	80
 
 enum {
@@ -206,3 +231,5 @@ enum {
 
     NUM_WIPES
 };
+
+
