@@ -19,46 +19,44 @@
 #include "globals.h"
 #include "funcs.h"
 
-SDL_Surface *screen;
-SDL_Surface *bkg;
+SDL_Surface* screen;
 
-// HACK: add tux trudging off after losing laser game...
 
-int sys_sound;
 SDL_Event  event;
 
-extern settings localsettings;
+
 
 /********************
   main : init stuff
 *********************/
 int main(int argc, char *argv[])
 {
-	Uint32          video_flags = 0,
-	                lib_flags   = 0;
-	int i;
-   
-	sys_sound = 1;      //default using system sounds
-	speed_up = 0;       //run at normal speed
-	show_tux4kids = 1;  //show tux4kids logo the first time in main menu
-	useEnglish = 1;     //default to no theme
-	debugOn = 0;        //default to not in debug mode
-	hidden = 0;         //default to no "hidden" background
+  Uint32 video_flags = 0,
+         lib_flags   = 0;
+  int i;
+
+  /* Initialize settings with hard-coded defaults: */ 
+  Opts_Initialize();
 
-	setupTheme(NULL);
 	srand(time(NULL));
 
-	LoadSettings();
-	DEBUGCODE { printf("Window setting from config file is: %s\n", localsettings.window );}
+	// This sets settings.default_data_path to the default theme file path:
+	SetupPaths(NULL);
 
-	if (strncmp ( localsettings.window, "yes", FNLEN ) == 0 ){
-		video_flags = (SDL_SWSURFACE | SDL_HWPALETTE);
-	} else {
-		video_flags = (SDL_FULLSCREEN | SDL_SWSURFACE | SDL_HWPALETTE);
+	LoadSettings();
+	DEBUGCODE { printf("Window setting from config file is: %d\n", settings.fullscreen);}
+
+	if (settings.fullscreen)
+        {
+	  video_flags = (SDL_FULLSCREEN | SDL_SWSURFACE | SDL_HWPALETTE);
+	} 
+        else
+        {
+	  video_flags = (SDL_SWSURFACE | SDL_HWPALETTE);
 	}
         
 	lib_flags = SDL_INIT_VIDEO;
-
+	/* FIXME this could go into something like HandleCommandArgs() */
 	// check command line args
 	if (argc > 1) 
 		for (i = 1; i < argc; i++) {
@@ -104,27 +102,27 @@ int main(int argc, char *argv[])
 		
 			if ((strcmp(argv[i], "-sp") == 0) |
 			    (strcmp(argv[i], "--speed") == 0)) 
-				speed_up = 1;
+				settings.speed_up = 1;
 
 			if ((strcmp(argv[i], "-d") == 0) |
 			    (strcmp(argv[i], "--debug") == 0)) 
-				debugOn = 1;
+				settings.debug_on = 1;
 
 			if ((strcmp(argv[i], "-s") == 0) |
 				(strcmp(argv[i], "--sound") == 0)) 
-				sys_sound = 1;
+				settings.sys_sound = 1;
 			
 			if ((strcmp(argv[i], "-ns") == 0) |
 			    (strcmp(argv[i], "--nosound") == 0)) 
-				sys_sound = 0;
+				settings.sys_sound = 0;
 			
 			if ((strcmp(argv[i], "--hidden") == 0) |
 			    (strcmp(argv[i], "-hidden") == 0)) 
-				hidden = 1;
+				settings.hidden = 1;
 			
 			if ((strcmp(argv[i], "-t") == 0) |
 			    (strcmp(argv[i], "--theme") == 0)) 
-				setupTheme( argv[++i] );
+				SetupPaths(argv[++i]);
 		}
 
 	DEBUGCODE {
@@ -133,12 +131,13 @@ int main(int argc, char *argv[])
 
 	lib_flags |= SDL_INIT_AUDIO;
 	
-	LibInit(lib_flags);
-	GraphicsInit(video_flags);
+	LibInit(lib_flags); /* calls SDL_Init(), TTF_Init(), some other settings */
+	GraphicsInit(video_flags); /* calls SDL_SetVideoMode(), a few others     */
 
-	if (sys_sound){
-	    Mix_VolumeMusic(localsettings.mus_volume);
-	    Mix_Volume(-1,localsettings.sfx_volume);
+	if (settings.sys_sound)
+        {
+	    Mix_VolumeMusic(settings.mus_volume);
+	    Mix_Volume(-1, settings.sfx_volume);
 	}
 
 	/* Fix: we should check config files/environment variables like LANG! */
@@ -146,10 +145,16 @@ int main(int argc, char *argv[])
 	LoadLang();
 	LoadKeyboard();
 
+	/* Now actually play the game: */
 	TitleScreen();
 
+
 	SaveSettings();
 
+	/* Release heap: */
+	Cleanup();
+
+
 	LOG( "---GAME DONE, EXIT---- Thank you.\n" );
 
 	return EXIT_SUCCESS;
