@@ -32,7 +32,7 @@
 #define END_FRAME_DY 2	//rise speed of ending animation text
 #define WIN_GAME_XAMP 4	//the xamplitide of winning game text circular motion
 #define WIN_GAME_YAMP 4	//the yamplitude of winning game text circular motion
-#define WIN_GAME_ANGLE_MULT 4	//the angle multiplier for winning game te xt circ motion
+#define WIN_GAME_ANGLE_MULT 4	//the angle multiplier for winning game text circ motion
 
 //tux frame lengths (number of frames each cell of animation frames on-screen)
 #define WALK_ONSCREEN	10
@@ -85,10 +85,10 @@ typedef struct {
 struct fishypoo {
     int alive;
     int can_eat;
-    unsigned char *word;
+    wchar_t* word;
     double x, y;
     int    w;
-    int    len;
+    size_t len;
     int    splat_time;
     double dy;
 } fish_object[MAX_FISHIES_HARD + 1];
@@ -125,7 +125,7 @@ struct tuxguy {
     int endx, endy;
     int state;
     int wordlen;
-    unsigned char word[MAX_WORD_SIZE + 1];
+    wchar_t word[MAX_WORD_SIZE + 1];
 } tux_object;
 
 struct splatter {
@@ -135,4 +135,7 @@ struct splatter {
 
 struct splatter null_splat;
 
+
+
+
 #endif
